==> v0.5.4.tar.gz: libarea/app/Languages/ua/web.php <==
<?php

/*
* The following language strings are used by the site directory.
*
* Следующие языковые строки используются Каталога сайтов.
*/

return [
    'more'              => 'Докладніше',
    'category'          => 'Категорія',
    'categories'        => 'Категорії',
    'audits'            => 'Аудит',
    'soft'              => 'Софт',
    'website'           => 'Сайт',
    'websites'          => 'Сайти',
    'on_website'        => 'На сайт',
    'deleted'           => 'Видалені',
    'facets'            => 'Фасети',
    'favorites'         => 'Закладки',
    'menu'              => 'Меню',
    'no'                => 'Ні',
    'yes'               => 'Так',
    'title'             => 'Назва',
    'description'       => 'Опис',
    'catalog'           => 'Каталог',
    'find'              => 'Знайти',
    'help'              => 'Підказка',
    'deny_replies'      => 'Заборонити відповіді?',
    'posted'            => 'Розміщений?',
    'necessarily'       => 'Обов\'язково до заповнення',
    'status'            => 'Статус посилання',
    'there_program'     => 'Є програма?',
    'there_forum'       => 'На сайті є форум?',
    'there_portal'      => 'Це портал?',
    'there_blog'        => 'Це особистий блог?',
    'there_reference'   => 'Це довідковий сайт (енциклопедія)?',
    'there_goods'       => 'На сайті є товари та послуги?',
    'hosted_github'     => 'Програма розміщена на GitHub?',
    'url_github'        => 'URL адреса репозиторію на GitHub',
    'related_posts'     => 'Пов\'язані пости',
    'desc_formed'       => 'Опис формується',
    'by_date'           => 'За датою',
    'top_view'          => 'За рейтингом',
    'new_sites'         => 'Нові сайти',
    'audits_view'       => 'Вимагають розгляду',
    'deleted_view'      => 'Видалені',
    'my_website'        => 'Мої сайти',
    'no_website'        => 'Сайтів поки що немає',
    'bookmarks'         => 'Мої закладки по сайтам',
    'bookmarks_view'    => 'Мої закладки',
    'no_bookmarks'      => 'Закладок поки що немає',
    'answers'           => 'Відповіді',
    'no_answers'        => 'Поки немає відповідей...',
    'characters'        => 'Символів',
    'remove'            => 'Видалити',
    'reply'             => 'Відповісти',
    'edit'              => 'Змінити',
    'cancel'            => 'Скасувати',
    'add'               => 'Додати',
    'markdown'          => 'Розмітка Мarkdown',
    'recommended'       => 'Рекомендовані',
    'my_website_info'   => 'Список сайтів доданих мною',
    'moderation'        => 'Модерація',
    'sign_in'           => 'Увійти',
    'registration'      => 'Реєстрація',
    'site_added'        => 'Сайт додано',

    'closed'            => 'Обговорення сайту заборонено. Автор чи персонал закрив обговорення.',

    'screenshot_time'   => 'Створення скріншота може тривати деякий час.',
 
    'audits_home_title' => 'Аудит сайтів',
    'audits_home_desc'  => 'Сайти на розгляді',
    'num_website'       => ['Сайт', 'Сайта', 'Сайтів'],
    
    'news'              => 'Новини та ЗМІ',
    'internet'          => 'Інтернет',
    'culture'           => 'Культура та мистецтво',
    'software'          => 'Програми',
    'reference_info'    => 'Довідкова інформація',
    'reference_help'    => 'Енциклопедії, довідники',
    'science'           => 'Наука та освіта',
    'business'          => 'Бізнес',
    'life'              => 'Домашнє вогнище',
    'cms'               => 'CMS',
    'life_help'         => 'Дітям, тварини, хобі...',
    'security'          => 'Безпека...',
    'society'           => 'Суспільство та політика',

    'contact_information'   => 'Контактна інформація',
    'telephone'             => 'Телефон',
    'email'                 => 'Email',
    'vk'                    => 'ВКонтакті (URL)',
    'telegram'              => 'Телеграм (URL)',

    'string_length'         => 'Некоректна довжина {name}',
    'website_correctness'   => 'Адреса (URL) сайту не є коректною',
    'site_replay'           => 'Такий сайт вже є у системі',

    'data_help'         => '<i class="gray-600">Формат заголовка:</i><br> «LibArea» — спільнота<br><br><i class="gray-600">Опис (без реклами):</i><br> ... Що є на сайті?<i>',
    
    'add_category'      => 'Додати категорію',
    'add_website'       => 'Додати сайт',
    'edit_website'      => 'Змінити сайт',
    
    'sidebar_info'      => 'Каталог сайтів, систематизованих за тематичними рубриками.',
    'banner_info'       => 'Каталог сайтів з анотаціями та скріншотами. <br>Фасетна рубрикація, пошук. Закладки з ресурсів з можливість голосувати за сайти, програми, рейтинг.',
    
    'main_title'        => 'Каталог сайтів',
    'main_desc'         => 'Список сайтів у каталозі розміщених у хронологічному порядку. Можливість пошуку, закладки, сортування за популярністю',
    
    'deleted_title'     => 'Віддалені сайти',
    'deleted_desc'      => '...',
    'audits_title'      => 'Аудит сайтів',
    'audits_desc'       => '...',

    'all'               => 'Всі',
    'github'            => 'GitHub',
    'forum'             => 'Форуми',
    'blog'              => 'Блоги',
    'portal'            => 'Портали',
    'reference'         => 'Енциклопедії',
    'goods'             => 'Товари та послуги',

    'top_title'         => '{name} — сайти за популярністю',
    'top_desc'          => 'Анонсований список сайтів за тематикою {description_info}',
    'all_title'         => '{name} — рубрика, сайти за датою',
    'all_desc'          => 'Сайти у хронологічному порядку у рубриці {description_info}',
];

==> v0.5.6.tar.gz: libarea/app/Languages/ua/web.php <==
<?php

/*
* The following language strings are used by the site directory.
*
* Следующие языковые строки используются Каталога сайтов.
*/

return [
    'more'              => 'Докладніше',
    'category'          => 'Категорія',
    'categories'        => 'Категорії',
    'audits'            => 'Аудит',
    'soft'              => 'Софт',
    'website'           => 'Сайт',
    'websites'          => 'Сайти',
    'comments'          => 'Коментарі',
    'on_website'        => 'На сайт',
    'deleted'           => 'Видалені',
    'facets'            => 'Фасети',
    'favorites'         => 'Закладки',
    'menu'              => 'Меню',
    'no'                => 'Ні',
    'yes'               => 'Так',
    'title'             => 'Назва',
    'description'       => 'Опис',
    'catalog'           => 'Каталог',
    'find'              => 'Знайти',
    'help'              => 'Підказка',
    'deny_replies'      => 'Заборонити відповіді?',
    'posted'            => 'Розміщений?',
    'necessarily'       => 'Обов\'язково до заповнення',
    'status'            => 'Оновити',
    'refresh'           => 'Refresh',
    'there_program'     => 'Є програма?',
    'there_forum'       => 'На сайті є форум?',
    'there_portal'      => 'Це портал?',
    'there_blog'        => 'Це особистий блог?',
    'there_reference'   => 'Це довідковий сайт (енциклопедія)?',
    'there_goods'       => 'На сайті є товари та послуги?',
    'hosted_github'     => 'Програма розміщена на GitHub?',
    'url_github'        => 'URL адреса репозиторію на GitHub',
    'related_posts'     => 'Пов\'язані пости',
    'desc_formed'       => 'Опис формується',
    'by_date'           => 'За датою',
    'top'               => 'TOP',
    'top_view'          => 'За рейтингом',
    'new_sites'         => 'Нові сайти',
    'audits_view'       => 'Вимагають розгляду',
    'deleted_view'      => 'Видалені',
    'my_website'        => 'Мої сайти',
    'no_website'        => 'Сайтів поки що немає',
    'bookmarks'         => 'Мої закладки по сайтам',
    'bookmarks_view'    => 'Мої закладки',
    'no_bookmarks'      => 'Закладок поки що немає',
    'answers'           => 'Відповіді',
    'no_answers'        => 'Поки немає відповідей...',
    'characters'        => 'Символів',
    'remove'            => 'Видалити',
    'reply'             => 'Відповісти',
    'edit'              => 'Змінити',
    'cancel'            => 'Скасувати',
    'add'               => 'Додати',
    'markdown'          => 'Розмітка Мarkdown',
    'recommended'       => 'Рекомендовані',
    'my_website_info'   => 'Список сайтів доданих мною',
    'moderation'        => 'Модерація',
    'sign_in'           => 'Увійти',
    'registration'      => 'Реєстрація',
    'site_added'        => 'Сайт додано',

    'closed'            => 'Обговорення сайту заборонено. Автор чи персонал закрив обговорення.',

    'screenshot_time'   => 'Створення скріншота може тривати деякий час.',
 
    'audits_home_title' => 'Аудит сайтів',
    'audits_home_desc'  => 'Сайти на розгляді',
    'num_website'       => ['Сайт', 'Сайта', 'Сайтів'],
    
    'news'              => 'Новини та ЗМІ',
    'internet'          => 'Інтернет',
    'culture'           => 'Культура та мистецтво',
    'software'          => 'Програми',
    'reference_info'    => 'Довідкова інформація',
    'reference_help'    => 'Енциклопедії, довідники',
    'science'           => 'Наука та освіта',
    'business'          => 'Бізнес',
    'life'              => 'Домашнє вогнище',
    'cms'               => 'CMS',
    'life_help'         => 'Дітям, тварини, хобі...',
    'security'          => 'Безпека...',
    'society'           => 'Суспільство та політика',

    'contact_information'   => 'Контактна інформація',
    'telephone'             => 'Телефон',
    'email'                 => 'Email',
    'vk'                    => 'ВКонтакті (URL)',
    'telegram'              => 'Телеграм (URL)',

    'string_length'         => 'Некоректна довжина {name}',
    'website_correctness'   => 'Адреса (URL) сайту не є коректною',
    'site_replay'           => 'Такий сайт вже є у системі',

    'data_help'         => '<i class="gray-600">Формат заголовка:</i><br> «LibArea» — спільнота<br><br><i class="gray-600">Опис (без реклами):</i><br> ... Що є на сайті?<i>',
    'admin_help'        => 'Закритий розділ доступний лише персоналу',
    
    'add_category'      => 'Додати категорію',
    'add_website'       => 'Додати сайт',
    'edit_website'      => 'Змінити сайт',
    
    'sidebar_info'      => 'Каталог сайтів, систематизованих за тематичними рубриками.',
    'banner_info'       => 'Каталог сайтів з анотаціями та скріншотами. <br>Фасетна рубрикація, пошук. Закладки з ресурсів з можливість голосувати за сайти, програми, рейтинг.',
    
    'main_title'        => 'Каталог сайтів',
    'main_desc'         => 'Список сайтів у каталозі розміщених у хронологічному порядку. Можливість пошуку, закладки, сортування за популярністю',
    
    'deleted_title'     => 'Віддалені сайти',
    'audits_title'      => 'Аудит сайтів',

    'all'               => 'Всі',
    'github'            => 'GitHub',
    'forum'             => 'Форуми',
    'blog'              => 'Блоги',
    'portal'            => 'Портали',
    'reference'         => 'Енциклопедії',
    'goods'             => 'Товари та послуги',

    'top_title'         => '{name} — сайти за популярністю',
    'top_desc'          => 'Анонсований список сайтів за тематикою {description_info}',
    'all_title'         => '{name} — рубрика, сайти за датою',
    'all_desc'          => 'Сайти у хронологічному порядку у рубриці {description_info}',
];
